.. highlight:: shell

============
Installation
============

From sources
------------

The sources for photoshop python api can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone https://github.com/loonghao/photoshop_python_api.git

Or download the `tarball`_:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/loonghao/photoshop_python_api
.. _tarball: https://github.com/loonghao/photoshop_python_api/master

Or you can install via pip.

.. code-block:: console

   $ pip install photoshop_python_api
